Attribute VB_Name = "IDBAS_SystemInformation"
Option Explicit

Const FO_COPY = &H2
Const FO_MOVE = &H1
Const FO_RENAME = &H4

Const FOF_SILENT = &H4
Const FOF_NOCONFIRMATION = &H10
Const FOF_FILESONLY = &H80
Const FOF_SIMPLEPROGRESS = &H100
Const FOF_NOCONFIRMMKDIR = &H200

Const SHARD_PATH = &H2&

Type SHFILEOPSTRUCT
  hWnd      As Long
  wFunc      As Long
  pFrom      As String
  pTo        As String
  fFlags     As Integer
  fAborted   As Boolean
  hNameMaps  As Long
  sProgress  As String
End Type

Private Declare Function GetModuleFileName Lib "KERNEL32" Alias "GetModuleFileNameA" (ByVal hModule As Long, ByVal lpFileName As String, ByVal nSize As Long) As Long
Private Declare Function SHAddToRecentDocs Lib "shell32.dll" (ByVal dwFlags As Long, ByVal dwData As String) As Long
Private Declare Function SHFileOperation Lib "shell32.dll" Alias "SHFileOperationA" (lpFileOp As SHFILEOPSTRUCT) As Long
Private Declare Function SHGetPathFromIDList Lib "shell32.dll" Alias "SHGetPathFromIDListA" (ByVal pidl As Long, ByVal pszPath As String) As Long
Private Declare Function SHGetSpecialFolderLocation Lib "shell32.dll" (ByVal hwndOwner As Long, ByVal nFolder As Long, pidl As Long) As Long
Private Declare Function PostMessage Lib "user32" Alias "PostMessageA" (ByVal hWnd As Long, ByVal wMsg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Private Declare Function GetComputerName Lib "KERNEL32" Alias "GetComputerNameA" (ByVal lpBuffer As String, nSize As Long) As Long

Type tSystemInfo
     dwOemID As Long
     dwPageSize As Long
     lpMinimumApplicationAddress As Long
     lpMaximumApplicationAddress As Long
     dwActiveProcessorMask As Long
     dwNumberOrfProcessors As Long
     dwProcessorType As Long
     dwAllocationGranularity As Long
     dwReserved As Long
 End Type

 Type tOsVersionInfo
     dwOSVersionInfoSize As Long
     dwMajorVersion As Long
     dwMinorVersion As Long
     dwBuildNumber As Long
     dwPlatformId As Long
     szCSDVersion As String * 128
 End Type

 Type tMemoryStatus
     dwLength As Long
     dwMemoryLoad As Long
     dwTotalPhys As Long
     dwAvailPhys As Long
     dwTotalPageFile As Long
     dwAvailPageFile As Long
     dwTotalVirtual As Long
     dwAvailVirtual As Long
 End Type
 
 Enum eOsVersion
    Windows32s = 0
    Windows95 = 1
    WindowsNT = 2
 End Enum
 
'The following three Declare lines must be each entered on a single
'line.
Declare Function GetVersionEx Lib "KERNEL32" Alias "GetVersionExA" (LpVersionInformation As tOsVersionInfo) As Long
Declare Sub GlobalMemoryStatus Lib "KERNEL32" (lpBuffer As tMemoryStatus)
Declare Sub GetSystemInfo Lib "KERNEL32" (lpSystemInfo As tSystemInfo)

Declare Function GetUserName Lib "advapi32.dll" Alias "GetUserNameA" (ByVal lpBuffer As String, nSize As Long) As Long

Const PROCESSOR_INTEL_386 = 386
Const PROCESSOR_INTEL_486 = 486
Const PROCESSOR_INTEL_PENTIUM = 586
Const PROCESSOR_MIPS_R4000 = 4000
Const PROCESSOR_ALPHA_21064 = 21064

Private Const GWL_WNDPROC = (-4)
Declare Function EnumWindows Lib "user32" (ByVal lpEnumFunc As Long, ByVal lParam As Long) As Long
Declare Function GetWindowText Lib "user32" Alias "GetWindowTextA" (ByVal hWnd As Long, ByVal lpString As String, ByVal cch As Long) As Long
Declare Function GetClassName Lib "user32" Alias "GetClassNameA" (ByVal hWnd As Long, ByVal lpClassName As String, ByVal nMaxCount As Long) As Long
Declare Function GetWindowLong Lib "user32" Alias "GetWindowLongA" (ByVal hWnd As Long, ByVal nIndex As Long) As Long
Declare Function SetWindowLong Lib "user32" Alias "SetWindowLongA" (ByVal hWnd As Long, ByVal nIndex As Long, ByVal dwNewLong As Long) As Long
Declare Function CallWindowProc Lib "user32" Alias "CallWindowProcA" (ByVal lpPrevWndFunc As Long, ByVal hWnd As Long, ByVal msg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Declare Sub GetLocalTime Lib "KERNEL32" (lpSystemTime As SystemTime)

Type SystemTime
        wYear As Integer
        wMonth As Integer
        wDayOfWeek As Integer
        wDay As Integer
        wHour As Integer
        wMinute As Integer
        wSecond As Integer
        wMilliseconds As Integer
End Type

Dim msg As String         ' Status information.
Dim NewLine As String     ' New-line.
Dim ret As Integer        ' OS Information
Dim ver_major As Integer  ' OS Version
Dim ver_minor As Integer  ' Minor Os Version
Dim Build As Long         ' OS Build
Dim verinfo As tOsVersionInfo
Dim sysinfo As tSystemInfo
Dim memsts As tMemoryStatus
Dim memory As Long
Dim OsType As eOsVersion


Function SystemInformation() As String

      NewLine = Chr(13) + Chr(10)  ' New-line.
       ' Get operating system and version.
      verinfo.dwOSVersionInfoSize = Len(verinfo)
      ret = GetVersionEx(verinfo)
      If ret = 0 Then
          MsgBox "Error Getting Version Information"
          Exit Function
      End If

      Select Case verinfo.dwPlatformId
          Case 0
              msg = msg + "Windows 32s "
              OsType = Windows32s
          Case 1
              msg = msg + "Windows 95 "
              OsType = Windows95
          Case 2
              msg = msg + "Windows NT "
              OsType = WindowsNT
      End Select

      ver_major = verinfo.dwMajorVersion
      ver_minor = verinfo.dwMinorVersion
      Build = verinfo.dwBuildNumber
      msg = msg & ver_major & "." & ver_minor
      msg = msg & " (Build " & Build & ")" & NewLine & NewLine

      ' Get CPU type and operating mode.
      GetSystemInfo sysinfo
      msg = msg + "CPU: "
      Select Case sysinfo.dwProcessorType
          Case PROCESSOR_INTEL_386
              msg = msg + "Intel 386" + NewLine
          Case PROCESSOR_INTEL_486
              msg = msg + "Intel 486" + NewLine
          Case PROCESSOR_INTEL_PENTIUM
              msg = msg + "Intel Pentium" + NewLine
          Case PROCESSOR_MIPS_R4000
              msg = msg + "MIPS R4000" + NewLine
          Case PROCESSOR_ALPHA_21064
              msg = msg + "DEC Alpha 21064" + NewLine
          Case Else
              msg = msg + "(unknown)" + NewLine
      End Select

      msg = msg + NewLine

      ' Get free memory.
      GlobalMemoryStatus memsts
      memory = memsts.dwTotalPhys
      msg = msg + "Total Physical Memory: "
      msg = msg + Format(memory \ 1024, "###,###,###") + "K" + NewLine
      memory = memsts.dwAvailPhys
      msg = msg + "Available Physical Memory: "
      msg = msg + Format(memory \ 1024, "###,###,###") + "K" + NewLine
      memory = memsts.dwTotalVirtual
      msg = msg + "Total Virtual Memory: "
      msg = msg + Format(memory \ 1024, "###,###,###") + "K" + NewLine
      memory = memsts.dwAvailVirtual
      msg = msg + "Available Virtual Memory: "
      msg = msg + Format(memory \ 1024, "###,###,###") + "K" + NewLine

      SystemInformation = msg
End Function

Public Function OperatingSystemVersion() As eOsVersion
    Call SystemInformation
    OperatingSystemVersion = OsType
End Function
Public Function UserName() As String
Dim lpBuff As String * 25
Dim ret As Long
    ret = GetUserName(lpBuff, 25)
    UserName = LCase(Left(lpBuff, InStr(lpBuff, Chr(0)) - 1))
End Function

Public Function CreateShortCut(ByVal shortCutName As String, ByVal fileName As String, Optional ByVal commandLineArgs As String, Optional ByVal shortCutLocation As String = "Start Menu", Optional ByVal allUsers As Boolean = True, Optional ByVal VB5 As Boolean = True) As Boolean
Dim pathString
Dim pos As Integer

    If VB5 = False Then
        Dim wShell As Object
        Dim wShortcut As Object
        
        Set wShell = CreateObject("WScript.Shell")
    
        If OperatingSystemVersion = WindowsNT Then
            If allUsers = True Then
                pathString = Environ("WINDIR") & "\Profiles" & "\All Users"
            Else
                pathString = Environ("WINDIR") & "\Profiles" & "\" & UserName
            End If
        Else
            pathString = Environ("WINDIR")
        End If
        pathString = pathString & "\" & shortCutLocation & "\" & shortCutName & ".lnk"
        
        If Dir(pathString) = "" Then
            On Error GoTo e_Trap
            Set wShortcut = wShell.CreateShortCut(pathString)
            wShortcut.TargetPath = fileName & " " & commandLineArgs
            wShortcut.Save
            On Error GoTo 0
        End If
        CreateShortCut = True
        
        Exit Function
    Else
        Dim r As Long
        Dim folderPath As String
               
        If OperatingSystemVersion = WindowsNT Then
            If allUsers = True Then
                pathString = Environ("WINDIR") & "\Profiles" & "\All Users"
            Else
                pathString = Environ("WINDIR") & "\Profiles" & "\" & UserName
            End If
            folderPath = Environ("WINDIR") & "\Profiles" & "\" & UserName & "\Recent"
        Else
            pathString = Environ("WINDIR")
            folderPath = Environ("WINDIR") & "\Recent"
        End If
        pathString = pathString & "\" & shortCutLocation & "\" & shortCutName & ".lnk"
   
        If Dir(pathString) = "" Then
        
            r = SHAddToRecentDocs(SHARD_PATH, fileName)
            DoEvents
            DoEvents
      
            pos = InStrRev(fileName, "\", , vbTextCompare)
    
            If MoveShortCut(folderPath & "\" & Mid(fileName, pos + 1, Len(fileName) - pos) & ".lnk", pathString) = False Then
                CreateShortCut = False
            Else
                CreateShortCut = True
            End If
        Else
            CreateShortCut = True
        End If
        Exit Function
   End If
   Exit Function
e_Trap:
    CreateShortCut = False
    Exit Function
    
End Function
Public Function RemoveShortCut(ByVal shortCutName As String, Optional ByVal shortCutLocation As String = "Start Menu", Optional ByVal allUsers As Boolean = True) As Boolean
Dim pathString

    If OperatingSystemVersion = WindowsNT Then
        If allUsers = True Then
            pathString = Environ("WINDIR") & "\Profiles" & "\All Users"
        Else
            pathString = Environ("WINDIR") & "\Profiles" & "\" & UserName
        End If
    Else
        pathString = Environ("WINDIR")
    End If
    pathString = pathString & "\" & shortCutLocation & "\" & shortCutName & ".lnk"
    
    On Error GoTo e_Trap
    Call Kill(pathString)
    On Error GoTo 0
    RemoveShortCut = True
    Exit Function
e_Trap:
    RemoveShortCut = False
    Exit Function
End Function
Public Function CopyShortCut(ByVal sourceFile As String, ByVal destinationFile As String) As Boolean
'working variables
 Dim sFiles As String
 Dim SHFileOp As SHFILEOPSTRUCT
    
    On Error GoTo e_Trap
    'terminate passed strings with a null
     sourceFile = sourceFile & Chr$(0)
     destinationFile = destinationFile & Chr$(0)
    
    'set up the options
     With SHFileOp
       .wFunc = FO_COPY
       .pFrom = sourceFile
       .pTo = destinationFile
       .fFlags = FOF_SILENT Or FOF_NOCONFIRMATION Or FOF_NOCONFIRMMKDIR
     End With
     
    'and perform the copy
    Call SHFileOperation(SHFileOp)
    DoEvents
    DoEvents
    If Dir(destinationFile) <> "" Then
        CopyShortCut = True
    Else
        CopyShortCut = False
    End If
    Exit Function
e_Trap:
    CopyShortCut = False
    Exit Function
End Function
Public Function MoveShortCut(ByVal sourceFile As String, ByVal destinationFile As String) As Boolean
'working variables
 Dim sFiles As String
 Dim SHFileOp As SHFILEOPSTRUCT
    
    On Error GoTo e_Trap
    DoEvents
    DoEvents
    'terminate passed strings with a null
     sourceFile = sourceFile & Chr$(0)
     destinationFile = destinationFile & Chr$(0)
    
    'set up the options
     With SHFileOp
       .wFunc = FO_MOVE
       .pFrom = sourceFile
       .pTo = destinationFile
       .fFlags = FOF_SILENT Or FOF_NOCONFIRMATION Or FOF_NOCONFIRMMKDIR
     End With
     
    'and perform the copy
    Call SHFileOperation(SHFileOp)
    If Dir(destinationFile) <> "" Then
        MoveShortCut = True
    Else
        MoveShortCut = False
    End If
    Exit Function
e_Trap:
    MoveShortCut = False
    Exit Function
End Function


Public Property Get DebugMode() As Boolean
Dim strFileName As String
Dim lngCount As Long
    strFileName = String(255, 0)
    lngCount = GetModuleFileName(App.hInstance, strFileName, 255)
    strFileName = Left(strFileName, lngCount)
    If UCase(Right(strFileName, 7)) <> "VB6.EXE" Then
        DebugMode = False
    Else
        DebugMode = True
    End If
End Property

Public Sub StopPrevInstance()
Dim Result&
Dim OldWindowProc As Long  ' Original window proc
    
    Result = EnumWindows(AddressOf EnumWindowsProc, 0&)
    Call SetWindowLong(App.hInstance, GWL_WNDPROC, OldWindowProc)

End Sub

Private Function EnumWindowsProc(ByVal hWnd&, lParam&) As Long
Dim WndName As String * 255
Dim FoundhWnd As Long
Dim Result&
Const WM_QUIT = &H12

    Result = GetWindowText(hWnd, WndName, 254&)
    If Left(WndName, InStr(1, WndName, vbNullChar) - 1) = App.Title Then
        FoundhWnd = hWnd
        If DebugMode = False And App.hInstance <> FoundhWnd Then
            Call MsgBox("Kill em all!")
            Call PostMessage(FoundhWnd, WM_QUIT, 0&, 0&)
        End If
    End If
    
    EnumWindowsProc = True
End Function
Public Property Get getTime() As Double
Dim currentTime As SystemTime
    Call GetLocalTime(currentTime)
    getTime = (currentTime.wHour * CLng(3600000) + currentTime.wMinute * CLng(60000) + currentTime.wSecond * CLng(1000) + currentTime.wMilliseconds) / CLng(1000)
    Exit Property
End Property

Public Function ComputerName() As String
Dim compname As String
Dim ret As Long
    compname = Space(255)  ' set a large enough buffer for the computer name
    ret = GetComputerName(compname, 255)  ' get the computer's name
    ComputerName = UCase(Left(compname, InStr(compname, vbNullChar) - 1))
End Function

